#ifndef NT2_INCLUDE_FUNCTIONS_ISTRIL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISTRIL_HPP_INCLUDED

#include <nt2/predicates/include/functions/istril.hpp>

#endif
